@@ -3,6 +3,7 @@ from django.http import HttpResponseRedirect
 from django.views.generic.simple import direct_to_template
 from django.contrib import admin
 from django.contrib import auth
+from django.contrib import messages
 
 from auth_additions.forms import UserChangeForm
 from admin_additions.patchers import add_actions, patch_admin
@@ -24,7 +25,7 @@ def duplicate_group(self, request, queryset):
     form = None
     
     if queryset.count() != 1:
-        self.message_user(request,
+        messages.error(request,
             "You may only duplicate one group at a time."
         )
         return HttpResponseRedirect(request.get_full_path())
