@@ -1,5 +1,10 @@
+from django.db.models.fields.related import SingleRelatedObjectDescriptor
 from django.contrib.auth.models import User
 
+USER_SUBCLASSES = [o for o in dir(User)
+                     if isinstance(getattr(User, o), SingleRelatedObjectDescriptor)
+                     and issubclass(getattr(User, o).related.model, User)]
+
 class EmailBackend(object):
     supports_object_permissions = False
     supports_anonymous_user = False
@@ -9,12 +14,13 @@ class EmailBackend(object):
         if '@' in username:
             for user in User.objects.filter(email=username, is_active=True):
                 if user.check_password(password):
-                    return user
+                    return self.get_user(user.pk)
         return None
     
     def get_user(self, user_id):
         try:
-            return User.objects.get(pk=user_id)
+            user = User.objects.select_related(*USER_SUBCLASSES).get(pk=user_id)
+            return ([getattr(user, s) for s in USER_SUBCLASSES if getattr(user, s)] or [user])[0]
         except User.DoesNotExist:
             return None
 
