@@ -40,12 +40,24 @@ class ExistingUserForm(forms.Form):
 # Extend the UserChangeForm to allow for the correct number of characters.
 USERNAME_LENGTH = User._meta.get_field_by_name('username')[0].max_length
 
+class UserEmailUniqueMixin(object):
+    """
+    Mixin this class if you require all email addresses (across all
+    sub-classes of User) to be unique.
+    """
+    def clean_email(self):
+        email = self.cleaned_data['email']
+        if User.objects.exclude(pk=self.instance.pk).filter(email=email, is_active=True).exists():
+            raise forms.ValidationError("That email address is in use. You may use <something>+email@example.com")
+        return email
+
 class UserChangeForm(UserChangeForm):
     username = forms.RegexField(
         label=_(u"Username"),
         max_length=USERNAME_LENGTH,
         regex=r"^[\w .@+-]+$",
-        help_text = _("Required. %s characters or fewer. Letters, digits and "
+        required=False,
+        help_text = _("Optional. %s characters or fewer. Letters, digits and "
                       "@/ /./+/-/_ only." % USERNAME_LENGTH),
         error_messages = {
             'invalid': _("This value may contain only letters, numbers and "
